(function ($, Drupal) {
  $.fn.extend({
    ajaxLoad(url) {
      $('body').addClass('loading');
      $.ajax({
        url: `${url}/ajax`,
        type: 'GET',
        cache: false,
        success(result) {
          $(
            '#media-file-explorer .top-bar .folder-form form .form-item .form-text',
          )[0].value = '';
          $('#media-file-explorer #subfolders').html(result.folders);
          $('#media-file-explorer #subfolders').removeClass('not-droppable');
          $('#media-file-explorer #subfolders').addClass(
            result.subfolders_class,
          );
          $('#media-file-explorer #subfolders').attr('data-id', result.fid);
          $('#media-file-explorer #navbar').html(result.navbar);
          $('#media-file-explorer .folder-breadcrumb-inner').html(
            result.breadcrumb,
          );
          $('#media-file-explorer .operations').html(result.actions);
          $('#media-file-explorer > .actions').html(result.actions_raw);
          $('#media-file-explorer .buttons').html(result.buttons);
          $('#media-file-explorer .up-button').html(result.up_button);
          $('h1.page-title').html(result.title);
          $('#media-file-explorer #preview').removeClass();
          $('#media-file-explorer #preview .preview-contents').html('');
          $('body').removeClass('loading');
          Drupal.attachBehaviors();
        },
        error(result) {
          const messages = new Drupal.Message();
          messages.add(Drupal.t('An error occurred'), {
            type: 'error',
          });
          $('body').removeClass('loading');
        },
      });
    },
  });

  $.fn.extend({
    ajaxWidgetLoad(url, stateParameters, widgetSettings) {
      const widgetId = stateParameters.field_name;
      const bundle = stateParameters.bundle;
      const entityTypeId = stateParameters.entity_type_id;

      $('body').addClass('loading');
      $.ajax({
        url: `${url}/widget/${entityTypeId}/${bundle}/${widgetId}/ajax`,
        type: 'POST',
        data: { request: widgetSettings },
        cache: false,
        success(result) {
          console.log(result);
          $('#media-file-explorer #subfolders').html(result.folders);
          $('#media-file-explorer #subfolders').removeClass('not-droppable');
          $('#media-file-explorer #subfolders').addClass(
            result.subfolders_class,
          );
          $('#media-file-explorer #subfolders').attr('data-id', result.fid);
          $('#media-file-explorer #navbar').html(result.navbar);
          $('#media-file-explorer .folder-breadcrumb-inner').html(
            result.breadcrumb,
          );
          $('#media-file-explorer .up-button').html(result.up_button);
          $('#media-file-explorer #preview').removeClass();
          $('#media-file-explorer #preview .preview-contents').html('');
          $('body').removeClass('loading');
          Drupal.attachBehaviors();
        },
        error(result) {
          const messages = new Drupal.Message();
          messages.add(Drupal.t('An error occurred'), {
            type: 'error',
          });
          $('body').removeClass('loading');
        },
      });
    },
  });

  $.fn.extend({
    ajaxWidgetUpdate(fid, parameters) {
      $(
        `input[data-media-folders-widget-value="${parameters.state_parameters.field_widget_id}"]`,
      )[0].value = fid;
      $(
        `input[data-media-folders-widget-update="${parameters.state_parameters.field_widget_id}"]`,
      ).trigger('mousedown');
      Drupal.dialog(document.getElementById('drupal-modal')).close();
    },
  });

  $.fn.extend({
    ajaxGetPreview() {
      const folder = $(this).find('a.folder-icon');
      if ($(this).hasClass('folder-file')) {
        const folderId = $('#subfolders').attr('data-id');
        const mid = $(this).attr('data-id');
        const dataExtension = folder.attr('data-ext');
        const dataSize = folder.attr('data-size');
        const details = `<div>${dataExtension} ${Drupal.t('file')}</div><div>${dataSize}</div>`;

        $.ajax({
          url: `/admin/content/file-explorer/${folderId}/${mid}/preview/ajax`,
          type: 'GET',
          success(result) {
            $('#preview .preview-contents').html('');
            $('#preview').addClass('open');
            setTimeout(function () {
              $('#preview .preview-contents').html(
                `${result.render}${details}`,
              );
            }, 300);
          },
        });
      } else if ($(this).hasClass('folder-folder')) {
        setTimeout(function () {
          const text = folder.find('span.title')[0].textContent;
          const desc = folder.attr('title');
          const dataCount = folder.attr('data-count');
          const details = `<div>${text}</div><div>${desc}</div><div>${dataCount} ${Drupal.t('items')}</div>`;
          $('#preview .preview-contents').html('');
          $('#preview').addClass('open');
          setTimeout(function () {
            $('#preview .preview-contents').html(`${details}`);
          }, 300);
        }, 500);
      }
    },
  });

  $.fn.extend({
    fileDrop(options) {
      const defaults = {
        callback: null,
      };
      options = $.extend(defaults, options);
      return this.each(function () {
        const $this = $(this);

        $this.on('dragleave', function (event) {
          event.stopPropagation();
          event.preventDefault();

          if ($(this).hasClass('folder-folder')) {
            $this.removeClass('droppable').removeClass('upload-droppable');
          } else {
            const relatedTarget = $(event.relatedTarget);
            if (relatedTarget.attr('id') !== 'subfolders') {
              if (!relatedTarget.parents('#subfolders').length) {
                $this.removeClass('droppable').removeClass('upload-droppable');
              }
            }
          }
        });

        $this.on('dragover dragenter', function (event) {
          event.stopPropagation();
          event.preventDefault();
          $this.addClass('droppable upload-droppable');
        });

        $this.on('drop', function (event) {
          event.stopPropagation();
          event.preventDefault();
          $this.removeClass('droppable').removeClass('upload-droppable');

          if ($(this).hasClass('not-droppable')) {
            return false;
          }

          if (typeof event.originalEvent.dataTransfer !== 'undefined') {
            const fid = $this.attr('data-id');
            const files = event.originalEvent.dataTransfer.files || [];
            event.originalEvent.dataTransfer.dropEffect = 'copy';

            if (options.callback) {
              options.callback(fid, files);
            }
          }

          return false;
        });
      });
    },
  });

  $.fn.extend({
    readFile(file) {
      return new Promise((resolve, reject) => {
        const reader = new FileReader();
        const name = file.name;
        const size = file.size;
        const type = file.type;
        reader.onload = function (evt) {
          const obj = {
            name,
            size,
            type,
            contents: evt.target.result,
          };
          resolve(obj);
        };

        reader.onerror = function (evt) {
          const obj = {
            name: null,
            size: null,
            type: null,
            contents: null,
          };
          resolve(obj);
        };

        reader.readAsDataURL(file);
      });
    },
  });

  $.fn.extend({
    readFiles(files) {
      return new Promise((resolve, reject) => {
        const uploadFiles = [];
        const filesLength = files.length;
        for (let i = 0; i < files.length; i++) {
          $(this)
            .readFile(files[i])
            .then((readerRs) => {
              if (readerRs) {
                uploadFiles.push(readerRs);
                if (files.length === uploadFiles.length) {
                  resolve(uploadFiles);
                }
              }
            })
            .catch((error) => {
              uploadFiles.push({});
            });
        }
      });
    },
  });

  $.fn.extend({
    ajaxUpload(fid, files) {
      if (files.length) {
        $('body').addClass('loading');
        $(this)
          .readFiles(files)
          .then((readerRs) => {
            if (readerRs) {
              $.ajax({
                url: `/file-explorer/${fid}/upload-file/ajax`,
                type: 'POST',
                data: { request: readerRs },
                cache: false,
                success(result) {
                  if (result.messages.length) {
                    const messages = new Drupal.Message();
                    for (let i = 0; i < result.messages.length; i++) {
                      messages.add(result.messages[i].message, {
                        type: result.messages[i].type,
                      });
                    }
                  }
                  const url = `/file-explorer/${fid}`;
                  const state = {
                    type: 'media-file-explorer',
                    url,
                  };
                  window.history.pushState(state, document.title, url);
                  $(this).ajaxLoad(url);
                },
                error(result) {
                  const messages = new Drupal.Message();
                  messages.add(Drupal.t('An error occurred'), {
                    type: 'error',
                  });
                  $('body').removeClass('loading');
                },
              });
            }
          })
          .catch((error) => {
            console.error('Error reading files:', error);
          });
      }
    },
  });

  $.fn.extend({
    ajaxMove(fid, toMove) {
      $('body').addClass('loading');
      $.ajax({
        url: `/file-explorer/${fid}/move-into/ajax`,
        type: 'POST',
        data: { objects: toMove },
        cache: false,
        success(result) {
          if (result.messages.length) {
            const messages = new Drupal.Message();
            for (let i = 0; i < result.messages.length; i++) {
              messages.add(result.messages[i].message, {
                type: result.messages[i].type,
              });
            }
          }
          if (result.messages[0].type === 'status') {
            const url = `/file-explorer/${fid}`;
            const state = {
              type: 'media-file-explorer',
              url,
            };
            window.history.pushState(state, document.title, url);
            $(this).ajaxLoad(url);
          } else {
            $('body').removeClass('loading');
          }
        },
        error(result) {
          const messages = new Drupal.Message();
          messages.add(Drupal.t('An error occurred'), {
            type: 'error',
          });
          $('body').removeClass('loading');
        },
      });
    },
  });
})(jQuery, Drupal);
