(function ($, Drupal, Sortable) {
  Drupal.behaviors.media_folder_management_widget = {
    attach(context, settings) {
      if ($(context)[0].nodeName === '#document') {
        $(
          once(
            'subfolders-folder-icon',
            '#subfolders .folder a.folder-icon',
            context,
          ),
        ).click(function (event) {
          event.preventDefault();
          event.stopPropagation();

          const folder = $(this).parent('.folder');

          if (folder.hasClass('folder-folder')) {
            return;
          }

          if (!event.ctrlKey && !event.shiftKey) {
            $('#subfolders .folder a.selected')
              .not($(this))
              .removeClass('selected');
            $('#subfolders .folder.selected')
              .not(folder)
              .removeClass('selected');
          }

          if (event.shiftKey && $('#subfolders .folder.selected').length) {
            const first = $('#subfolders .folder.selected').first();
            const firstIndex = $('#subfolders .folder').index(first);
            const thisIndex = $('#subfolders .folder').index(folder);
            const min = firstIndex < thisIndex ? firstIndex : thisIndex;
            const max = firstIndex < thisIndex ? thisIndex : firstIndex;

            $('#subfolders .folder').each(function (index) {
              if (
                index >= min &&
                index <= max &&
                $('#subfolders .folder.selected').length <
                  settings.media_folder_management.selection_remaining
              ) {
                $(this).addClass('selected');
                $(this).find('a.folder-icon').addClass('selected');
              }
            });
          } else if (
            $('#subfolders .folder.selected').length <
            settings.media_folder_management.selection_remaining
          ) {
            $(this).toggleClass('selected');
            folder.toggleClass('selected');
          }

          if ($('#subfolders .folder.selected').length === 1) {
            $('#subfolders .folder.selected').ajaxGetPreview();
          } else {
            $('#preview').removeClass();
            $('#preview .preview-contents').html('');
          }

          if ($('#subfolders .folder.selected').length) {
            $('#folders-details span.details').show();
          } else {
            $('#folders-details span.details').hide();
          }
        });

        $(once('subfolders-navbar', '#navbar a', context)).click(
          function (event) {
            event.preventDefault();
            event.stopPropagation();

            const url = $(this).attr('href');
            $(this).ajaxWidgetLoad(
              url,
              settings.media_folder_management.state_parameters,
              settings.media_folder_management.widget_settings,
            );
          },
        );

        $(
          once('navbar-expand', '#explorer #navbar > ul li > span', context),
        ).click(function (event) {
          $(this).parent().toggleClass('active-trail');
        });

        $(
          once(
            'widget-subfolders-submit',
            '#media-file-explorer.widget #folders-details input',
            context,
          ),
        ).click(function (event) {
          event.preventDefault();
          event.stopPropagation();

          if ($('#subfolders .folder.selected').length) {
            const toInsert = [];
            const selected = $('#subfolders .folder.selected');
            selected.each(function () {
              toInsert.push($(this).attr('data-id'));
            });

            $(this).ajaxWidgetUpdate(
              toInsert.join(','),
              settings.media_folder_management,
            );
          }
        });

        $(once('subfolders-folder', '#subfolders .folder', context)).dblclick(
          function (event) {
            event.preventDefault();
            event.stopPropagation();

            if ($(this).find('a').hasClass('folder-icon-file')) {
              const fid = $('#subfolders').attr('data-id');
              $(this).ajaxWidgetUpdate(fid, settings.media_folder_management);
            } else {
              event.preventDefault();
              event.stopPropagation();
              const url = $(this).find('a').attr('href');
              $(this).ajaxWidgetLoad(
                url,
                settings.media_folder_management.state_parameters,
                settings.media_folder_management.widget_settings,
              );
            }
          },
        );

        $(
          once(
            'subfolders-back',
            '#media-file-explorer.widget .top-bar .up-button',
            context,
          ),
        ).click(function (event) {
          event.preventDefault();
          event.stopPropagation();

          if ($(this).find('a').length) {
            const url = $(this).find('a').attr('href');
            $(this).ajaxWidgetLoad(
              url,
              settings.media_folder_management.state_parameters,
              settings.media_folder_management.widget_settings,
            );
          }
        });

        $(
          once(
            'subfolders-breadcrumb',
            '#media-file-explorer.widget .top-bar .folder-breadcrumb a',
            context,
          ),
        ).click(function (event) {
          event.preventDefault();
          event.stopPropagation();

          const url = $(this).attr('href');
          $(this).ajaxWidgetLoad(
            url,
            settings.media_folder_management.state_parameters,
            settings.media_folder_management.widget_settings,
          );
        });

        $(
          once(
            'subfolders-submit',
            '#media-file-explorer.widget #folders-details input',
            context,
          ),
        ).click(function (event) {
          event.preventDefault();
          event.stopPropagation();

          if ($('#board .folder.selected').length) {
            const toInsert = [];
            const selected = $('#board .folder.selected');
            selected.each(function () {
              toInsert.push($(this).attr('data-id'));
            });

            $(this).ajaxWidgetUpdate(
              toInsert.join(','),
              settings.media_folder_management,
            );
          }
        });

        $(window).on('dialogopen', (e, ui) => {
          Drupal.attachBehaviors();
        });
      }
    },
  };

  Drupal.behaviors.MediaFoldersWidgetSortable = {
    attach(context) {
      const selection = context.querySelectorAll('.js-media-folders-selection');
      selection.forEach((widget) => {
        Sortable.create(widget, {
          draggable: '.js-media-folders-item',
          onEnd: () => {
            $(widget)
              .children()
              .each((index, child) => {
                $(child).find('.js-media-folders-item-weight')[0].value = index;
              });
          },
        });
      });
    },
  };

  Drupal.behaviors.MediaFoldersWidgetToggleWeight = {
    attach(context) {
      const strings = {
        show: Drupal.t('Show file item weights'),
        hide: Drupal.t('Hide file item weights'),
      };
      const mediaFoldersToggle = once(
        'media-folders-toggle',
        '.js-media-folders-widget-toggle-weight',
        context,
      );
      $(mediaFoldersToggle).on('click', (e) => {
        e.preventDefault();
        const $target = $(e.currentTarget);
        e.currentTarget.textContent = $target.hasClass('active')
          ? strings.show
          : strings.hide;
        $target
          .toggleClass('active')
          .closest('.js-media-folders-widget')
          .find('.js-media-folders-item-weight')
          .parent()
          .toggle();
      });
      mediaFoldersToggle.forEach((item) => {
        item.textContent = strings.show;
      });

      $(once('media-folders-toggle', '.js-media-folders-item-weight', context))
        .parent()
        .hide();
    },
  };

  Drupal.behaviors.MediaFoldersWidgetDisableButton = {
    attach(context) {
      once(
        'media-folders-disable',
        '.js-media-folders-open-button[data-disabled-focus="true"]',
        context,
      ).forEach((button) => {
        $(button).focus();
        setTimeout(() => {
          $(button).attr('disabled', 'disabled');
        }, 50);
      });
    },
  };
})(jQuery, Drupal, Sortable);
