<?php

namespace Drupal\media_folder_management\Controller;

use Drupal\Core\Cache\Cache;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\Cookie;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Class Cookie Controller.
 */
class CookieController extends ControllerBase {

  /**
   * The request service.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(RequestStack $request_stack) {
    $this->requestStack = $request_stack;
  }

  /**
   * Sets cookies.
   */
  public function setCookie($name = NULL, $value = FALSE) {
    $destination = $this->requestStack->getCurrentRequest()->query->get('destination');

    $response = new Response();
    $cookie = Cookie::create($name, $value, 0, '/', NULL, FALSE);
    $response->headers->setCookie($cookie);
    $response->send();

    return new RedirectResponse($destination);
  }

  /**
   * Sets cookies ajax.
   */
  public function setCookieAjax($name = NULL, $value = FALSE) {
    $response = new JsonResponse(['name' => $name, 'value' => $value]);
    $cookie = Cookie::create($name, $value, 0, '/', NULL, FALSE);
    $response->headers->setCookie($cookie);
    Cache::invalidateTags(['media_folder_page']);

    return $response;
  }

}
