<?php

namespace Drupal\media_folder_management\Entity\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines an access control handler for media folder file items.
 */
class MediaFolderFileAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    if ($account->hasPermission('administer folders') || $account->hasPermission('bypass media folder files permissions')) {
      return AccessResult::allowed()->cachePerPermissions();
    }

    switch ($operation) {
      case 'view':
        if (MediaFolderFileAccessCheck::hasViewFileAccess($entity, $account)) {
          return AccessResult::allowed()->cachePerPermissions();
        }
        return AccessResult::forbidden()->cachePerPermissions();

      case 'update':
        if (MediaFolderFileAccessCheck::hasEditFileAccess($entity, $account)) {
          return AccessResult::allowed()->cachePerPermissions();
        }
        return AccessResult::forbidden()->cachePerPermissions();

      case 'lock':
        if (MediaFolderFileAccessCheck::hasLockFileAccess($entity, $account)) {
          return AccessResult::allowed();
        }
        return AccessResult::forbidden()->cachePerPermissions();

      case 'delete':
        if (MediaFolderFileAccessCheck::hasDeleteFileAccess($entity, $account)) {
          return AccessResult::allowed()->cachePerPermissions();
        }
        return AccessResult::forbidden()->cachePerPermissions();

      default:
        return AccessResult::forbidden()->cachePerPermissions();
    }

    return AccessResult::forbidden()->cachePerPermissions();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    if ($account->hasPermission('administer folders') || $account->hasPermission('bypass media folder files permissions')) {
      return AccessResult::allowed()->cachePerPermissions();
    }

    return MediaFolderFileAccessCheck::accessAddFileToFolder($account);
  }

}
