<?php

namespace Drupal\media_folder_management\Entity\Form;

use Drupal\Core\Entity\ContentEntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Provides a form for deleting a media_folder_management entity.
 *
 * @ingroup media_folder_management
 */
class MediaFolderFileLockForm extends ContentEntityConfirmFormBase {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {

    $form['log'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Revision log message'),
      '#description' => $this->t('Briefly describe the changes you have made.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    $action = !$this->entity->field_locked->value ? $this->t('Lock') : $this->t('Unlock');

    return $this->t('@action file %name?', [
      '@action' => $action,
      '%name' => $this->entity->label(),
    ]);
  }

  /**
   * {@inheritdoc}
   *
   * If the delete command is canceled, return to the media folder file list.
   */
  public function getCancelUrl() {
    return new Url('entity.media_folder_file.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return !$this->entity->field_locked->value ? $this->t('Lock') : $this->t('Unlock');
  }

  /**
   * {@inheritdoc}
   *
   * Delete the entity and log the event. logger() replaces the watchdog.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $entity = $this->getEntity();
    $action = !$this->entity->field_locked->value ? 1 : 0;
    $action_string = !$this->entity->field_locked->value ? $this->t('Locked') : $this->t('Unlocked');
    $log = (!empty($form_state->getValue('log'))) ? ' | ' . $form_state->getValue('log') : '';

    $entity->set('field_locked', $action);
    $entity->setNewRevision();
    $entity->setRevisionLogMessage($this->t('@action, @log', [
      '@action' => $action_string,
      '@log' => $log,
    ]));
    $entity->save();

    $form_state->setRedirect('entity.media_folder_file.collection');
  }

}
