<?php

namespace Drupal\media_folder_management\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure settings for the media folder file.
 */
class MediaFolderFileConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'media_folder_management_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'media_folder_management.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('media_folder_management.settings');

    $form['config'] = [
      '#type' => 'details',
      '#title' => $this->t('Configuration'),
      '#open' => TRUE,
    ];

    $form['config']['page_name'] = [
      '#type' => 'textfield',
      '#required' => TRUE,
      '#title' => $this->t('Media folder file page title'),
      '#default_value' => $config->get('page_name'),
    ];

    $form['config']['default_view'] = [
      '#type' => 'select',
      '#options' => [
        'thumbs' => $this->t('Folder view'),
        'list' => $this->t('List view'),
      ],
      '#required' => TRUE,
      '#title' => $this->t('Default View Mode'),
      '#default_value' => $config->get('default_view'),
    ];

    $form['config']['default_order'] = [
      '#type' => 'select',
      '#options' => [
        'az' => $this->t('Alphabetic ascending'),
        'za' => $this->t('Alphabetic descending'),
        'date-asc' => $this->t('Date ascending'),
        'date-desc' => $this->t('Date descending'),
      ],
      '#required' => TRUE,
      '#title' => $this->t('Default Order'),
      '#default_value' => $config->get('default_order'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('media_folder_management.settings')
      ->set('default_view', $form_state->getValue('default_view'))
      ->set('default_order', $form_state->getValue('default_order'))
      ->set('page_name', $form_state->getValue('page_name'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
